==> jc-1.4.0.tar.gz: java/util/HashMap__24HashIterator.h <==
// final class java.util.HashMap$HashIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 563b3a999d26041d java_util_HashMap__24HashIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_HashMap__24HashIterator_H_
#define _JC_java_util_HashMap__24HashIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_HashMap__24HashEntry$object;

// Typedefs
typedef struct _jc_java_util_HashMap__24HashIterator$sub_refs	_jc_java_util_HashMap__24HashIterator$sub_refs;
typedef struct _jc_java_util_HashMap__24HashIterator$sub_nonrefs	_jc_java_util_HashMap__24HashIterator$sub_nonrefs;
typedef struct _jc_java_util_HashMap__24HashIterator$refs	_jc_java_util_HashMap__24HashIterator$refs;
typedef struct _jc_java_util_HashMap__24HashIterator$nonrefs	_jc_java_util_HashMap__24HashIterator$nonrefs;
typedef struct _jc_java_util_HashMap__24HashIterator$object	_jc_java_util_HashMap__24HashIterator$object;

typedef const struct _jc_java_util_HashMap__24HashIterator$vmethods	_jc_java_util_HashMap__24HashIterator$vmethods;
typedef const struct _jc_java_util_HashMap__24HashIterator$vtable	_jc_java_util_HashMap__24HashIterator$vtable;
typedef const struct _jc_java_util_HashMap__24HashIterator$vtype	_jc_java_util_HashMap__24HashIterator$vtype;

// Constructors
extern void _jc_java_util_HashMap__24HashIterator$method$_init$c385d6043dd3cff2(_jc_env *, struct _jc_java_util_HashMap__24HashIterator$object *, struct _jc_java_util_HashMap$object *, jint);

// Virtual methods
extern jboolean _jc_java_util_HashMap__24HashIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_java_util_HashMap__24HashIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_HashMap__24HashIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_java_util_HashMap__24HashIterator$object *);
extern void _jc_java_util_HashMap__24HashIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_java_util_HashMap__24HashIterator$object *);
extern void _jc_java_util_HashMap__24HashIterator$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_HashMap__24HashIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_HashMap__24HashIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_java_util_HashMap__24HashIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_java_util_HashMap__24HashIterator$method_info$remove$fd50149979e1f350;
extern _jc_method _jc_java_util_HashMap__24HashIterator$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_util_HashMap__24HashIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_java_util_HashMap__24HashIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_java_util_HashMap__24HashIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_java_util_HashMap__24HashIterator$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_HashMap__24HashIterator$object *);
};

// Vtable
struct _jc_java_util_HashMap__24HashIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_HashMap__24HashIterator$vmethods	java_util_HashMap__24HashIterator;
};

// Vtype
struct _jc_java_util_HashMap__24HashIterator$vtype {
	_jc_type			type;
	_jc_java_util_HashMap__24HashIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_HashMap__24HashIterator$sub_refs {
	struct _jc_java_util_HashMap__24HashEntry$object	*last;
	struct _jc_java_util_HashMap__24HashEntry$object	*next;
	struct _jc_java_util_HashMap$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_HashMap__24HashIterator$refs {
    _jc_java_util_HashMap__24HashIterator$sub_refs	java_util_HashMap__24HashIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_HashMap__24HashIterator$sub_nonrefs {
	jint	type;
	jint	knownMod;
	jint	count;
	jint	idx;
};

// Non-reference instance fields (object)
struct _jc_java_util_HashMap__24HashIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_HashMap__24HashIterator$sub_nonrefs	java_util_HashMap__24HashIterator;
};

// Object instance structure
struct _jc_java_util_HashMap__24HashIterator$object {
	_jc_java_util_HashMap__24HashIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_HashMap__24HashIterator$vtype	*vtype;
	_jc_java_util_HashMap__24HashIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_HashMap__24HashIterator$vtype _jc_java_util_HashMap__24HashIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_HashMap__24HashIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_HashMap__24HashIterator$class_object;

#endif	/* _JC_java_util_HashMap__24HashIterator_H_ */

==> jc-1.4.6.tar.gz: java/util/HashMap__24HashIterator.h <==
// final class java.util.HashMap$HashIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 563b3a999d26041d java_util_HashMap__24HashIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_HashMap__24HashIterator_H_
#define _JC_java_util_HashMap__24HashIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_HashMap__24HashEntry$object;

// Typedefs
typedef struct _jc_java_util_HashMap__24HashIterator$sub_refs	_jc_java_util_HashMap__24HashIterator$sub_refs;
typedef struct _jc_java_util_HashMap__24HashIterator$sub_nonrefs	_jc_java_util_HashMap__24HashIterator$sub_nonrefs;
typedef struct _jc_java_util_HashMap__24HashIterator$refs	_jc_java_util_HashMap__24HashIterator$refs;
typedef struct _jc_java_util_HashMap__24HashIterator$nonrefs	_jc_java_util_HashMap__24HashIterator$nonrefs;
typedef struct _jc_java_util_HashMap__24HashIterator$object	_jc_java_util_HashMap__24HashIterator$object;

typedef const struct _jc_java_util_HashMap__24HashIterator$vmethods	_jc_java_util_HashMap__24HashIterator$vmethods;
typedef const struct _jc_java_util_HashMap__24HashIterator$vtable	_jc_java_util_HashMap__24HashIterator$vtable;
typedef const struct _jc_java_util_HashMap__24HashIterator$vtype	_jc_java_util_HashMap__24HashIterator$vtype;

// Constructors
extern void _jc_java_util_HashMap__24HashIterator$method$_init$c385d6043dd3cff2(_jc_env *, struct _jc_java_util_HashMap__24HashIterator$object *, struct _jc_java_util_HashMap$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_HashMap__24HashIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_java_util_HashMap__24HashIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_HashMap__24HashIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_java_util_HashMap__24HashIterator$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_HashMap__24HashIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_java_util_HashMap__24HashIterator$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_HashMap__24HashIterator$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_HashMap__24HashIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_HashMap__24HashIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_java_util_HashMap__24HashIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_java_util_HashMap__24HashIterator$method_info$remove$fd50149979e1f350;
extern _jc_method _jc_java_util_HashMap__24HashIterator$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_util_HashMap__24HashIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_java_util_HashMap__24HashIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_java_util_HashMap__24HashIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_java_util_HashMap__24HashIterator$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_HashMap__24HashIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_HashMap__24HashIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_HashMap__24HashIterator$vmethods	java_util_HashMap__24HashIterator;
};

// Vtype
struct _jc_java_util_HashMap__24HashIterator$vtype {
	_jc_type			type;
	_jc_java_util_HashMap__24HashIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_HashMap__24HashIterator$sub_refs {
	struct _jc_java_util_HashMap__24HashEntry$object	*last;
	struct _jc_java_util_HashMap__24HashEntry$object	*next;
	struct _jc_java_util_HashMap$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_HashMap__24HashIterator$refs {
    _jc_java_util_HashMap__24HashIterator$sub_refs	java_util_HashMap__24HashIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_HashMap__24HashIterator$sub_nonrefs {
	jint	type;
	jint	knownMod;
	jint	count;
	jint	idx;
};

// Non-reference instance fields (object)
struct _jc_java_util_HashMap__24HashIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_HashMap__24HashIterator$sub_nonrefs	java_util_HashMap__24HashIterator;
};

// Object instance structure
struct _jc_java_util_HashMap__24HashIterator$object {
	_jc_java_util_HashMap__24HashIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_HashMap__24HashIterator$vtype	*vtype;
	_jc_java_util_HashMap__24HashIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_HashMap__24HashIterator$vtype _jc_java_util_HashMap__24HashIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_HashMap__24HashIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_HashMap__24HashIterator$class_object;

#endif	/* _JC_java_util_HashMap__24HashIterator_H_ */
